import django
from django.urls import path, include
from django.contrib import admin

admin.autodiscover()


urlpatterns = [
    path('jet/', include('jet.urls', 'jet')),
    path('jet/dashboard/', include('jet.dashboard.urls', 'jet-dashboard')),
    path('admin/doc/', include('django.contrib.admindocs.urls')),
    path('admin/', admin.site.urls),
]



"""
Next Generation of django-jet (Modern template for Django admin interface with improved functionality)
"""

__version__ = '1.0.15'
__author__ = 'Geex Arts, Technology Innovation Network, Djungle Studio'
__license__ = 'AGPLv3'
__copyright__ = '2015-2018, Geex Arts. 2019-2020, Technology Innovation Network'



import django
from django.urls import path
from django.views.i18n import JavaScriptCatalog

from jet.dashboard import dashboard
from jet.dashboard.views import update_dashboard_modules_view, add_user_dashboard_module_view, \
    update_dashboard_module_collapse_view, remove_dashboard_module_view, UpdateDashboardModuleView, \
    load_dashboard_module_view, reset_dashboard_view

app_name = 'dashboard'

urlpatterns = [
    path(
        'module/<int:pk>/',
        UpdateDashboardModuleView.as_view(),
        name='update_module'
    ),
    path(
        'update_dashboard_modules/',
        update_dashboard_modules_view,
        name='update_dashboard_modules'
    ),
    path(
        'add_user_dashboard_module/',
        add_user_dashboard_module_view,
        name='add_user_dashboard_module'
    ),
    path(
        'update_dashboard_module_collapse/',
        update_dashboard_module_collapse_view,
        name='update_dashboard_module_collapse'
    ),
    path(
        'remove_dashboard_module/',
        remove_dashboard_module_view,
        name='remove_dashboard_module'
    ),
    path(
        'load_dashboard_module/<int:pk>/',
        load_dashboard_module_view,
        name='load_dashboard_module'
    ),
    path(
        'reset_dashboard/',
        reset_dashboard_view,
        name='reset_dashboard'
    ),
    path(
        'jsi18n/',
        JavaScriptCatalog.as_view(),
        {'packages': 'jet'},
        name='jsi18n'
    ),
]

urlpatterns += dashboard.urls.get_urls()



import os
from setuptools import setup, find_packages


def read(fname):
    path = os.path.join(os.path.dirname(__file__), fname)
    try:
        file = open(path, encoding='utf-8')
    except TypeError:
        file = open(path)
    return file.read()


setup(
    name='django-djet2',
    version=__import__('jet').__version__,
    description='Next Generation of django-jet (Modern template for Django admin interface with improved functionality)',
    long_description=read('README.rst'),
    url='https://github.com/djungle-io/django-djet2',
    maintainer='Djungle Studio',
    maintainer_email='tech@djungle.io',
    packages=find_packages(),
    license='AGPLv3',
    python_requires='>=3',
    keywords=['django', 'admin'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Framework :: Django :: 4.0',
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Environment :: Web Environment',
        'Topic :: Software Development',
        'Topic :: Software Development :: User Interfaces',
    ],
    zip_safe=False,
    include_package_data=True,
    install_requires=['Django'],
    long_description_content_type='text/x-rst',
    project_urls={
        'Source': 'https://github.com/djungle-io/django-djet2',
        'Tracker': 'https://github.com/djungle-io/django-djet2/issues',
    },
)
